from .problems.Clique.QuboClique import QUBOClique
from .problems.Salesman.QuboSalesman import QUBOSalesman
from .problems.Hamiltonian.QuboHam import QUBOHam
from .problems.Knapsack.QuboKnapsack import QUBOKnapsack
from .problems.MaxWeightClique.QuboMaxWeightClique import QUBOMaxWeightClique



